import React from 'react';
import { Modal } from 'antd';
import { ExclamationCircleOutlined } from '@ant-design/icons';

interface ConfirmDialogProps {
  title?: string;
  content?: string;
  onConfirm: () => void | Promise<void>;
  onCancel?: () => void;
  confirmText?: string;
  cancelText?: string;
  type?: 'info' | 'success' | 'error' | 'warning' | 'confirm';
  loading?: boolean;
}

const ConfirmDialog = {
  show: ({
    title = '确认操作',
    content = '您确定要执行此操作吗？',
    onConfirm,
    onCancel,
    confirmText = '确定',
    cancelText = '取消',
    type = 'confirm',
    loading = false,
  }: ConfirmDialogProps) => {
    const modalConfig = {
      title,
      content,
      okText: confirmText,
      cancelText,
      onOk: onConfirm,
      onCancel,
      confirmLoading: loading,
      centered: true,
    };

    switch (type) {
      case 'info':
        return Modal.info(modalConfig);
      case 'success':
        return Modal.success(modalConfig);
      case 'error':
        return Modal.error(modalConfig);
      case 'warning':
        return Modal.warning(modalConfig);
      case 'confirm':
      default:
        return Modal.confirm({
          ...modalConfig,
          icon: <ExclamationCircleOutlined />,
        });
    }
  },

  // 删除确认对话框
  delete: (props: Omit<ConfirmDialogProps, 'type'>) => {
    return ConfirmDialog.show({
      ...props,
      title: props.title || '确认删除',
      content: props.content || '删除后无法恢复，您确定要删除吗？',
      type: 'error',
      confirmText: props.confirmText || '删除',
    });
  },

  // 批量删除确认对话框
  batchDelete: (count: number, props?: Partial<ConfirmDialogProps>) => {
    return ConfirmDialog.show({
      title: '确认批量删除',
      content: `您选择了 ${count} 项数据，删除后无法恢复，确定要删除吗？`,
      type: 'error',
      confirmText: '删除',
      ...props,
    });
  },

  // 状态变更确认对话框
  changeStatus: (status: string, props?: Partial<ConfirmDialogProps>) => {
    return ConfirmDialog.show({
      title: '确认状态变更',
      content: `确定要将状态变更为"${status}"吗？`,
      type: 'warning',
      ...props,
    });
  },
};

export default ConfirmDialog; 