import React from 'react';
import { Modal, Form, FormProps } from 'antd';
import type { ModalProps } from 'antd';

interface FormModalProps extends Omit<ModalProps, 'onOk'> {
  title: string;
  visible: boolean;
  onCancel: () => void;
  onOk: (values: any) => void | Promise<void>;
  loading?: boolean;
  form?: any;
  children: React.ReactNode;
  formProps?: FormProps;
  width?: number;
  okText?: string;
  cancelText?: string;
}

const FormModal: React.FC<FormModalProps> = ({
  title,
  visible,
  onCancel,
  onOk,
  loading = false,
  form,
  children,
  formProps = {},
  width = 600,
  okText = '确定',
  cancelText = '取消',
  ...modalProps
}) => {
  const [formInstance] = Form.useForm(form);

  const handleOk = async () => {
    try {
      const values = await formInstance.validateFields();
      await onOk(values);
    } catch (error) {
      console.error('表单验证失败:', error);
    }
  };

  const handleCancel = () => {
    formInstance.resetFields();
    onCancel();
  };

  return (
    <Modal
      title={title}
      open={visible}
      onOk={handleOk}
      onCancel={handleCancel}
      confirmLoading={loading}
      width={width}
      okText={okText}
      cancelText={cancelText}
      destroyOnClose
      {...modalProps}
    >
      <Form
        form={formInstance}
        layout="vertical"
        preserve={false}
        {...formProps}
      >
        {children}
      </Form>
    </Modal>
  );
};

export default FormModal; 