import React from 'react';
import { Tag } from 'antd';
import type { TagProps } from 'antd';
import {
  USER_STATUS_COLORS,
  USER_STATUS_LABELS,
  CALL_STATUS_COLORS,
  CALL_STATUS_LABELS,
  DOCUMENT_STATUS_COLORS,
  DOCUMENT_STATUS_LABELS,
  APPOINTMENT_STATUS_COLORS,
  APPOINTMENT_STATUS_LABELS,
  TRANSLATOR_STATUS_COLORS,
  TRANSLATOR_STATUS_LABELS,
  PAYMENT_STATUS_COLORS,
  PAYMENT_STATUS_LABELS,
} from '@/constants';

type StatusType = 
  | 'user'
  | 'call'
  | 'document'
  | 'appointment'
  | 'translator'
  | 'payment';

interface StatusTagProps extends Omit<TagProps, 'color'> {
  type: StatusType;
  status: string;
}

const getStatusConfig = (type: StatusType, status: string) => {
  switch (type) {
    case 'user':
      return {
        color: USER_STATUS_COLORS[status as keyof typeof USER_STATUS_COLORS],
        label: USER_STATUS_LABELS[status as keyof typeof USER_STATUS_LABELS],
      };
    case 'call':
      return {
        color: CALL_STATUS_COLORS[status as keyof typeof CALL_STATUS_COLORS],
        label: CALL_STATUS_LABELS[status as keyof typeof CALL_STATUS_LABELS],
      };
    case 'document':
      return {
        color: DOCUMENT_STATUS_COLORS[status as keyof typeof DOCUMENT_STATUS_COLORS],
        label: DOCUMENT_STATUS_LABELS[status as keyof typeof DOCUMENT_STATUS_LABELS],
      };
    case 'appointment':
      return {
        color: APPOINTMENT_STATUS_COLORS[status as keyof typeof APPOINTMENT_STATUS_COLORS],
        label: APPOINTMENT_STATUS_LABELS[status as keyof typeof APPOINTMENT_STATUS_LABELS],
      };
    case 'translator':
      return {
        color: TRANSLATOR_STATUS_COLORS[status as keyof typeof TRANSLATOR_STATUS_COLORS],
        label: TRANSLATOR_STATUS_LABELS[status as keyof typeof TRANSLATOR_STATUS_LABELS],
      };
    case 'payment':
      return {
        color: PAYMENT_STATUS_COLORS[status as keyof typeof PAYMENT_STATUS_COLORS],
        label: PAYMENT_STATUS_LABELS[status as keyof typeof PAYMENT_STATUS_LABELS],
      };
    default:
      return {
        color: 'default',
        label: status,
      };
  }
};

const StatusTag: React.FC<StatusTagProps> = ({ type, status, ...props }) => {
  const { color, label } = getStatusConfig(type, status);

  return (
    <Tag color={color} {...props}>
      {label || status}
    </Tag>
  );
};

export default StatusTag; 