import { Layout, Button, Avatar, Dropdown, Typography, Space, Badge, Switch } from 'antd';
import {
  MenuUnfoldOutlined,
  MenuFoldOutlined,
  BellOutlined,
  UserOutlined,
  LogoutOutlined,
  SettingOutlined,
  SunOutlined,
  MoonOutlined,
  MobileOutlined,
} from '@ant-design/icons';
import { useSidebar, useAuth, useTheme, useNotifications } from '@/store';
import { useNavigate } from 'react-router-dom';

const { Header } = Layout;
const { Text } = Typography;

const AppHeader = () => {
  const { sidebarCollapsed, toggleSidebar } = useSidebar();
  const { user, logout } = useAuth();
  const { theme, toggleTheme } = useTheme();
  const { notifications, unreadCount } = useNotifications();
  const navigate = useNavigate();

  const userMenuItems = [
    {
      key: 'profile',
      icon: <UserOutlined />,
      label: '个人资料',
    },
    {
      key: 'settings',
      icon: <SettingOutlined />,
      label: '设置',
    },
    {
      type: 'divider' as const,
    },
    {
      key: 'logout',
      icon: <LogoutOutlined />,
      label: '退出登录',
      onClick: logout,
    },
  ];

  const notificationMenuItems = notifications.slice(0, 5).map((notification, index) => ({
    key: `notification-${index}`,
    label: (
      <div>
        <Text strong>{notification.title}</Text>
        <br />
        <Text type="secondary" style={{ fontSize: '12px' }}>
          {notification.message}
        </Text>
      </div>
    ),
  }));

  const handleMobileView = () => {
    navigate('/mobile/home');
  };

  return (
    <Header
      style={{
        position: 'fixed',
        top: 0,
        zIndex: 1,
        display: 'flex',
        alignItems: 'center',
        justifyContent: 'space-between',
        padding: '0 24px',
        background: theme === 'dark' ? '#001529' : '#fff',
        borderBottom: `1px solid ${theme === 'dark' ? '#1f1f1f' : '#f0f0f0'}`,
        marginLeft: sidebarCollapsed ? 80 : 240,
        width: sidebarCollapsed ? 'calc(100% - 80px)' : 'calc(100% - 240px)',
      }}
    >
      <div style={{ display: 'flex', alignItems: 'center' }}>
        <Button
          type="text"
          icon={sidebarCollapsed ? <MenuUnfoldOutlined /> : <MenuFoldOutlined />}
          onClick={toggleSidebar}
          style={{
            fontSize: '16px',
            width: 64,
            height: 64,
          }}
        />
      </div>

      <Space size="middle">
        <Button
          type="text"
          icon={<MobileOutlined />}
          onClick={handleMobileView}
          style={{ fontSize: '16px' }}
          title="切换到移动端视图"
        />

        <Switch
          checkedChildren={<MoonOutlined />}
          unCheckedChildren={<SunOutlined />}
          checked={theme === 'dark'}
          onChange={toggleTheme}
        />

        <Dropdown
          menu={{ items: notificationMenuItems }}
          placement="bottomRight"
          arrow
        >
          <Badge count={unreadCount} size="small">
            <Button
              type="text"
              icon={<BellOutlined />}
              style={{ fontSize: '16px' }}
            />
          </Badge>
        </Dropdown>

        <Dropdown
          menu={{ items: userMenuItems }}
          placement="bottomRight"
          arrow
        >
          <Space style={{ cursor: 'pointer' }}>
            <Avatar icon={<UserOutlined />} />
            <Text>{user?.name || '管理员'}</Text>
          </Space>
        </Dropdown>
      </Space>
    </Header>
  );
};

export default AppHeader; 