import { FC } from 'react';
import { useNavigate, useLocation } from 'react-router-dom';

interface NavItem {
  path: string;
  label: string;
  icon: string;
}

const navItems: NavItem[] = [
  { path: '/mobile/home', label: '首页', icon: '🏠' },
  { path: '/mobile/call', label: '通话', icon: '📞' },
  { path: '/mobile/documents', label: '文档', icon: '📄' },
  { path: '/mobile/appointments', label: '预约', icon: '📅' },
  { path: '/mobile/settings', label: '设置', icon: '⚙️' },
];

const MobileNavigation: FC = () => {
  const navigate = useNavigate();
  const location = useLocation();

  const handleNavigation = (path: string) => {
    navigate(path);
  };

  return (
    <div style={styles.container}>
      {navItems.map((item) => {
        const isActive = location.pathname === item.path;
        return (
          <button
            key={item.path}
            style={{
              ...styles.navItem,
              ...(isActive ? styles.activeNavItem : {}),
            }}
            onClick={() => handleNavigation(item.path)}
          >
            <span style={{
              ...styles.icon,
              ...(isActive ? styles.activeIcon : {}),
            }}>
              {item.icon}
            </span>
            <span style={{
              ...styles.label,
              ...(isActive ? styles.activeLabel : {}),
            }}>
              {item.label}
            </span>
          </button>
        );
      })}
    </div>
  );
};

const styles = {
  container: {
    display: 'flex',
    flexDirection: 'row' as const,
    backgroundColor: '#fff',
    borderTop: '1px solid #e0e0e0',
    padding: '8px 4px',
    justifyContent: 'space-around',
    alignItems: 'center',
    position: 'absolute' as const,
    bottom: 0,
    left: 0,
    right: 0,
    height: '80px',
    boxShadow: '0 -2px 4px rgba(0, 0, 0, 0.1)',
    zIndex: 1000,
  },
  navItem: {
    flex: 1,
    display: 'flex',
    flexDirection: 'column' as const,
    alignItems: 'center',
    justifyContent: 'center',
    padding: '8px 4px',
    borderRadius: '8px',
    border: 'none',
    backgroundColor: 'transparent',
    cursor: 'pointer',
    transition: 'all 0.2s ease',
  },
  activeNavItem: {
    backgroundColor: '#f0f8ff',
  },
  icon: {
    fontSize: '20px',
    marginBottom: '4px',
    opacity: 0.6,
    transition: 'opacity 0.2s ease',
  },
  activeIcon: {
    opacity: 1,
  },
  label: {
    fontSize: '12px',
    color: '#666',
    textAlign: 'center' as const,
    transition: 'color 0.2s ease',
  },
  activeLabel: {
    color: '#1890ff',
    fontWeight: '600' as const,
  },
};

export default MobileNavigation; 