import { FC } from 'react';
import { useNavigate, useLocation } from 'react-router-dom';

interface NavItem {
  path: string;
  label: string;
  icon: string;
}

const navItems: NavItem[] = [
  { path: '/mobile/home', label: '首页', icon: '🏠' },
  { path: '/mobile/call', label: '通话', icon: '📞' },
  { path: '/mobile/documents', label: '文档', icon: '📄' },
  { path: '/mobile/appointments', label: '预约', icon: '📅' },
  { path: '/mobile/settings', label: '设置', icon: '⚙️' },
];

const MobileNavigation: FC = () => {
  const navigate = useNavigate();
  const location = useLocation();

  const handleNavigation = (path: string) => {
    navigate(path);
  };

  const styles = {
    container: {
      position: 'fixed' as const,
      bottom: 0,
      left: 0,
      right: 0,
      height: '60px',
      backgroundColor: '#ffffff',
      borderTop: '1px solid #e8e8e8',
      display: 'flex',
      justifyContent: 'space-around',
      alignItems: 'center',
      zIndex: 1000,
      boxShadow: '0 -2px 10px rgba(0, 0, 0, 0.1)',
    },
    navItem: {
      display: 'flex',
      flexDirection: 'column' as const,
      alignItems: 'center',
      justifyContent: 'center',
      padding: '8px',
      cursor: 'pointer',
      transition: 'all 0.3s ease',
      borderRadius: '8px',
      minWidth: '50px',
    },
    activeNavItem: {
      backgroundColor: '#f0f8ff',
      transform: 'scale(1.05)',
    },
    icon: {
      fontSize: '20px',
      marginBottom: '4px',
    },
    label: {
      fontSize: '10px',
      fontWeight: '500',
      color: '#666',
    },
    activeLabel: {
      color: '#1890ff',
      fontWeight: '600',
    },
  };

  return (
    <div style={styles.container}>
      {navItems.map((item) => {
        const isActive = location.pathname === item.path;
        return (
          <div
            key={item.path}
            style={{
              ...styles.navItem,
              ...(isActive ? styles.activeNavItem : {}),
            }}
            onClick={() => handleNavigation(item.path)}
          >
            <span style={styles.icon}>{item.icon}</span>
            <span 
              style={{
                ...styles.label,
                ...(isActive ? styles.activeLabel : {}),
              }}
            >
              {item.label}
            </span>
          </div>
        );
      })}
    </div>
  );
};

export default MobileNavigation; 