import { FC, useState } from 'react';

const SettingsScreen: FC = () => {
  const [notifications, setNotifications] = useState(true);
  const [autoConnect, setAutoConnect] = useState(false);
  const [language, setLanguage] = useState('zh');

  return (
    <div style={styles.container}>
      <div style={styles.content}>
        {/* 用户信息 */}
        <div style={styles.section}>
          <h3 style={styles.sectionTitle}>用户信息</h3>
          <div style={styles.userProfile}>
            <div style={styles.avatar}>👤</div>
            <div style={styles.userInfo}>
              <div style={styles.userName}>张三</div>
              <div style={styles.userEmail}>zhang.san@example.com</div>
              <div style={styles.userPlan}>高级会员</div>
            </div>
            <button style={styles.editButton}>编辑</button>
          </div>
        </div>

        {/* 账户设置 */}
        <div style={styles.section}>
          <h3 style={styles.sectionTitle}>账户设置</h3>
          <div style={styles.settingsList}>
            <div style={styles.settingItem}>
              <div style={styles.settingInfo}>
                <span style={styles.settingLabel}>💳 套餐管理</span>
                <span style={styles.settingValue}>高级会员 - 剩余120分钟</span>
              </div>
              <span style={styles.settingArrow}>›</span>
            </div>
            
            <div style={styles.settingItem}>
              <div style={styles.settingInfo}>
                <span style={styles.settingLabel}>💰 充值续费</span>
                <span style={styles.settingValue}>管理您的套餐和充值</span>
              </div>
              <span style={styles.settingArrow}>›</span>
            </div>
            
            <div style={styles.settingItem}>
              <div style={styles.settingInfo}>
                <span style={styles.settingLabel}>📊 使用统计</span>
                <span style={styles.settingValue}>查看详细使用记录</span>
              </div>
              <span style={styles.settingArrow}>›</span>
            </div>
          </div>
        </div>

        {/* 应用设置 */}
        <div style={styles.section}>
          <h3 style={styles.sectionTitle}>应用设置</h3>
          <div style={styles.settingsList}>
            <div style={styles.settingItem}>
              <div style={styles.settingInfo}>
                <span style={styles.settingLabel}>🌐 界面语言</span>
                <select 
                  value={language} 
                  onChange={(e) => setLanguage(e.target.value)}
                  style={styles.settingSelect}
                >
                  <option value="zh">中文</option>
                  <option value="en">English</option>
                  <option value="es">Español</option>
                </select>
              </div>
            </div>
            
            <div style={styles.settingItem}>
              <div style={styles.settingInfo}>
                <span style={styles.settingLabel}>🔔 推送通知</span>
                <span style={styles.settingValue}>接收预约和通话提醒</span>
              </div>
              <label style={styles.toggle}>
                <input
                  type="checkbox"
                  checked={notifications}
                  onChange={(e) => setNotifications(e.target.checked)}
                  style={styles.toggleInput}
                />
                <span style={styles.toggleSlider}></span>
              </label>
            </div>
            
            <div style={styles.settingItem}>
              <div style={styles.settingInfo}>
                <span style={styles.settingLabel}>🔗 自动连接</span>
                <span style={styles.settingValue}>自动连接首选译员</span>
              </div>
              <label style={styles.toggle}>
                <input
                  type="checkbox"
                  checked={autoConnect}
                  onChange={(e) => setAutoConnect(e.target.checked)}
                  style={styles.toggleInput}
                />
                <span style={styles.toggleSlider}></span>
              </label>
            </div>
          </div>
        </div>

        {/* 帮助支持 */}
        <div style={styles.section}>
          <h3 style={styles.sectionTitle}>帮助支持</h3>
          <div style={styles.settingsList}>
            <div style={styles.settingItem}>
              <div style={styles.settingInfo}>
                <span style={styles.settingLabel}>❓ 使用帮助</span>
                <span style={styles.settingValue}>查看使用指南和常见问题</span>
              </div>
              <span style={styles.settingArrow}>›</span>
            </div>
            
            <div style={styles.settingItem}>
              <div style={styles.settingInfo}>
                <span style={styles.settingLabel}>💬 联系客服</span>
                <span style={styles.settingValue}>在线客服 24/7</span>
              </div>
              <span style={styles.settingArrow}>›</span>
            </div>
            
            <div style={styles.settingItem}>
              <div style={styles.settingInfo}>
                <span style={styles.settingLabel}>⭐ 评价反馈</span>
                <span style={styles.settingValue}>帮助我们改进产品</span>
              </div>
              <span style={styles.settingArrow}>›</span>
            </div>
          </div>
        </div>

        {/* 其他 */}
        <div style={styles.section}>
          <h3 style={styles.sectionTitle}>其他</h3>
          <div style={styles.settingsList}>
            <div style={styles.settingItem}>
              <div style={styles.settingInfo}>
                <span style={styles.settingLabel}>📄 隐私政策</span>
                <span style={styles.settingValue}>了解我们如何保护您的隐私</span>
              </div>
              <span style={styles.settingArrow}>›</span>
            </div>
            
            <div style={styles.settingItem}>
              <div style={styles.settingInfo}>
                <span style={styles.settingLabel}>📋 服务条款</span>
                <span style={styles.settingValue}>查看服务使用条款</span>
              </div>
              <span style={styles.settingArrow}>›</span>
            </div>
            
            <div style={styles.settingItem}>
              <div style={styles.settingInfo}>
                <span style={styles.settingLabel}>ℹ️ 关于我们</span>
                <span style={styles.settingValue}>版本 v1.0.0</span>
              </div>
              <span style={styles.settingArrow}>›</span>
            </div>
          </div>
        </div>

        {/* 退出登录 */}
        <div style={styles.section}>
          <button style={styles.logoutButton}>
            🚪 退出登录
          </button>
        </div>
      </div>
    </div>
  );
};

const styles = {
  container: {
    display: 'flex',
    flexDirection: 'column' as const,
    height: '100%',
    backgroundColor: '#f5f5f5',
  },
  content: {
    flex: 1,
    padding: '16px',
    paddingBottom: '100px',
  },
  section: {
    marginBottom: '24px',
  },
  sectionTitle: {
    fontSize: '18px',
    fontWeight: 'bold',
    color: '#333',
    margin: '0 0 16px 0',
  },
  userProfile: {
    display: 'flex',
    alignItems: 'center',
    padding: '20px',
    backgroundColor: '#fff',
    borderRadius: '12px',
    boxShadow: '0 2px 8px rgba(0, 0, 0, 0.1)',
  },
  avatar: {
    width: '60px',
    height: '60px',
    borderRadius: '50%',
    backgroundColor: '#1890ff',
    display: 'flex',
    alignItems: 'center',
    justifyContent: 'center',
    fontSize: '24px',
    color: '#fff',
    marginRight: '16px',
  },
  userInfo: {
    flex: 1,
  },
  userName: {
    fontSize: '18px',
    fontWeight: 'bold',
    color: '#333',
    marginBottom: '4px',
  },
  userEmail: {
    fontSize: '14px',
    color: '#666',
    marginBottom: '4px',
  },
  userPlan: {
    fontSize: '12px',
    color: '#1890ff',
    fontWeight: 'bold',
  },
  editButton: {
    padding: '8px 16px',
    backgroundColor: '#1890ff',
    color: '#fff',
    border: 'none',
    borderRadius: '6px',
    cursor: 'pointer',
    fontSize: '14px',
  },
  settingsList: {
    backgroundColor: '#fff',
    borderRadius: '12px',
    overflow: 'hidden',
    boxShadow: '0 2px 8px rgba(0, 0, 0, 0.1)',
  },
  settingItem: {
    display: 'flex',
    alignItems: 'center',
    justifyContent: 'space-between',
    padding: '16px',
    borderBottom: '1px solid #f0f0f0',
    cursor: 'pointer',
  },
  settingInfo: {
    flex: 1,
  },
  settingLabel: {
    display: 'block',
    fontSize: '16px',
    color: '#333',
    marginBottom: '4px',
  },
  settingValue: {
    display: 'block',
    fontSize: '14px',
    color: '#666',
  },
  settingSelect: {
    padding: '4px 8px',
    border: '1px solid #d9d9d9',
    borderRadius: '4px',
    fontSize: '14px',
    marginTop: '4px',
  },
  settingArrow: {
    fontSize: '18px',
    color: '#999',
  },
  toggle: {
    position: 'relative' as const,
    display: 'inline-block',
    width: '50px',
    height: '24px',
  },
  toggleInput: {
    opacity: 0,
    width: 0,
    height: 0,
  },
  toggleSlider: {
    position: 'absolute' as const,
    cursor: 'pointer',
    top: 0,
    left: 0,
    right: 0,
    bottom: 0,
    backgroundColor: '#ccc',
    transition: '0.4s',
    borderRadius: '24px',
  },
  logoutButton: {
    width: '100%',
    padding: '16px',
    backgroundColor: '#ff4d4f',
    color: '#fff',
    border: 'none',
    borderRadius: '12px',
    cursor: 'pointer',
    fontSize: '16px',
    fontWeight: 'bold',
  },
};

export default SettingsScreen; 