import { 
  User, 
  TranslationCall, 
  DocumentTranslation, 
  Appointment, 
  Translator, 
  Payment, 
  DashboardStats, 
  ChartData, 
  SystemSettings, 
  Notification,
  SystemLog,
  Language
} from '@/types';

// 语言列表
export const mockLanguages: Language[] = [
  { code: 'zh-CN', name: '中文（简体）', level: 'native' },
  { code: 'en-US', name: 'English', level: 'fluent' },
  { code: 'ja-JP', name: '日本語', level: 'fluent' },
  { code: 'ko-KR', name: '한국어', level: 'intermediate' },
  { code: 'es-ES', name: 'Español', level: 'intermediate' },
  { code: 'fr-FR', name: 'Français', level: 'basic' },
  { code: 'de-DE', name: 'Deutsch', level: 'basic' },
  { code: 'ru-RU', name: 'Русский', level: 'basic' },
];

// 用户数据
export const mockUsers: User[] = [
  {
    id: '1',
    email: 'admin@translatepro.com',
    name: '管理员',
    phone: '+86 138 0013 8000',
    avatar: 'https://api.dicebear.com/7.x/avataaars/svg?seed=admin',
    role: 'admin',
    status: 'active',
    createdAt: '2024-01-01T00:00:00Z',
    updatedAt: '2024-12-27T10:00:00Z',
    lastLoginAt: '2024-12-27T10:00:00Z',
    preferences: {
      language: 'zh-CN',
      timezone: 'Asia/Shanghai',
      notifications: { email: true, sms: true, push: true },
      theme: 'light'
    },
    subscription: {
      id: 'sub_1',
      userId: '1',
      plan: 'enterprise',
      status: 'active',
      startDate: '2024-01-01T00:00:00Z',
      endDate: '2025-01-01T00:00:00Z',
      features: ['unlimited_calls', 'priority_support', 'advanced_analytics']
    }
  },
  {
    id: '2',
    email: 'user1@example.com',
    name: '张三',
    phone: '+86 138 0013 8001',
    avatar: 'https://api.dicebear.com/7.x/avataaars/svg?seed=user1',
    role: 'user',
    status: 'active',
    createdAt: '2024-02-01T00:00:00Z',
    updatedAt: '2024-12-26T15:30:00Z',
    lastLoginAt: '2024-12-26T15:30:00Z',
    preferences: {
      language: 'zh-CN',
      timezone: 'Asia/Shanghai',
      notifications: { email: true, sms: false, push: true },
      theme: 'auto'
    },
    subscription: {
      id: 'sub_2',
      userId: '2',
      plan: 'premium',
      status: 'active',
      startDate: '2024-02-01T00:00:00Z',
      endDate: '2025-02-01T00:00:00Z',
      features: ['unlimited_ai_calls', 'document_translation', 'priority_support']
    }
  },
  {
    id: '3',
    email: 'user2@example.com',
    name: 'John Smith',
    phone: '+1 555 0123',
    avatar: 'https://api.dicebear.com/7.x/avataaars/svg?seed=user2',
    role: 'user',
    status: 'active',
    createdAt: '2024-03-01T00:00:00Z',
    updatedAt: '2024-12-25T09:15:00Z',
    lastLoginAt: '2024-12-25T09:15:00Z',
    preferences: {
      language: 'en-US',
      timezone: 'America/New_York',
      notifications: { email: true, sms: true, push: false },
      theme: 'dark'
    },
    subscription: {
      id: 'sub_3',
      userId: '3',
      plan: 'basic',
      status: 'active',
      startDate: '2024-03-01T00:00:00Z',
      endDate: '2025-03-01T00:00:00Z',
      features: ['limited_ai_calls', 'basic_support']
    }
  },
  {
    id: '4',
    email: 'translator1@example.com',
    name: '李译员',
    phone: '+86 138 0013 8004',
    avatar: 'https://api.dicebear.com/7.x/avataaars/svg?seed=translator1',
    role: 'translator',
    status: 'active',
    createdAt: '2024-01-15T00:00:00Z',
    updatedAt: '2024-12-27T08:00:00Z',
    lastLoginAt: '2024-12-27T08:00:00Z',
    preferences: {
      language: 'zh-CN',
      timezone: 'Asia/Shanghai',
      notifications: { email: true, sms: true, push: true },
      theme: 'light'
    }
  },
  {
    id: '5',
    email: 'user3@example.com',
    name: '王五',
    phone: '+86 138 0013 8005',
    avatar: 'https://api.dicebear.com/7.x/avataaars/svg?seed=user3',
    role: 'user',
    status: 'inactive',
    createdAt: '2024-04-01T00:00:00Z',
    updatedAt: '2024-12-20T14:20:00Z',
    lastLoginAt: '2024-12-15T10:30:00Z',
    preferences: {
      language: 'zh-CN',
      timezone: 'Asia/Shanghai',
      notifications: { email: false, sms: false, push: false },
      theme: 'light'
    },
    subscription: {
      id: 'sub_5',
      userId: '5',
      plan: 'free',
      status: 'active',
      startDate: '2024-04-01T00:00:00Z',
      endDate: '2025-04-01T00:00:00Z',
      features: ['limited_free_calls']
    }
  }
];

// 翻译通话数据
export const mockTranslationCalls: TranslationCall[] = [
  {
    id: 'call_1',
    callId: 'CALL-2024-001',
    userId: '2',
    clientName: '张三',
    clientPhone: '+86 138 0013 8001',
    type: 'ai',
    status: 'completed',
    sourceLanguage: 'zh-CN',
    targetLanguage: 'en-US',
    startTime: '2024-12-27T09:00:00Z',
    endTime: '2024-12-27T09:15:00Z',
    duration: 900,
    cost: 15.0,
    rating: 5,
    feedback: '翻译质量很好，语音清晰',
    transcription: '你好，我想预订一个酒店房间。',
    translation: 'Hello, I would like to book a hotel room.',
    translatorId: '4',
    translatorName: '李译员',
    translatorPhone: '+86 138 0013 8004'
  },
  {
    id: 'call_2',
    callId: 'CALL-2024-002',
    userId: '3',
    clientName: 'John Smith',
    clientPhone: '+1 555 0123',
    type: 'human',
    status: 'completed',
    sourceLanguage: 'en-US',
    targetLanguage: 'zh-CN',
    startTime: '2024-12-26T14:30:00Z',
    endTime: '2024-12-26T15:00:00Z',
    duration: 1800,
    cost: 45.0,
    rating: 4,
    feedback: '译员很专业，但有点网络延迟',
    translatorId: '4',
    translatorName: '李译员',
    translatorPhone: '+86 138 0013 8004'
  },
  {
    id: 'call_3',
    callId: 'CALL-2024-003',
    userId: '2',
    clientName: '张三',
    clientPhone: '+86 138 0013 8001',
    type: 'video',
    status: 'active',
    sourceLanguage: 'zh-CN',
    targetLanguage: 'ja-JP',
    startTime: '2024-12-27T10:30:00Z',
    cost: 30.0,
    translatorId: '4',
    translatorName: '李译员',
    translatorPhone: '+86 138 0013 8004'
  },
  {
    id: 'call_4',
    callId: 'CALL-2024-004',
    userId: '5',
    clientName: '王五',
    clientPhone: '+86 138 0013 8005',
    type: 'sign',
    status: 'cancelled',
    sourceLanguage: 'zh-CN',
    targetLanguage: 'en-US',
    startTime: '2024-12-25T16:00:00Z',
    cost: 0,
    feedback: '用户取消了通话'
  }
];

// 文档翻译数据
export const mockDocumentTranslations: DocumentTranslation[] = [
  {
    id: 'doc_1',
    userId: '2',
    fileName: '商业合同.pdf',
    fileSize: 2048576,
    fileType: 'application/pdf',
    fileUrl: '/uploads/contracts/business-contract.pdf',
    translatedFileUrl: '/uploads/contracts/business-contract-en.pdf',
    sourceLanguage: 'zh-CN',
    targetLanguage: 'en-US',
    status: 'completed',
    progress: 100,
    cost: 120.0,
    pageCount: 12,
    wordCount: 3500,
    translatorId: '4',
    createdAt: '2024-12-25T10:00:00Z',
    updatedAt: '2024-12-26T16:30:00Z',
    completedAt: '2024-12-26T16:30:00Z',
    quality: 'professional'
  },
  {
    id: 'doc_2',
    userId: '3',
    fileName: 'Technical Manual.docx',
    fileSize: 1536000,
    fileType: 'application/vnd.openxmlformats-officedocument.wordprocessingml.document',
    fileUrl: '/uploads/manuals/technical-manual.docx',
    sourceLanguage: 'en-US',
    targetLanguage: 'zh-CN',
    status: 'processing',
    progress: 65,
    cost: 85.0,
    pageCount: 8,
    wordCount: 2800,
    translatorId: '4',
    createdAt: '2024-12-26T14:00:00Z',
    updatedAt: '2024-12-27T10:30:00Z',
    quality: 'professional'
  },
  {
    id: 'doc_3',
    userId: '2',
    fileName: '产品说明书.pdf',
    fileSize: 512000,
    fileType: 'application/pdf',
    fileUrl: '/uploads/manuals/product-manual.pdf',
    sourceLanguage: 'zh-CN',
    targetLanguage: 'ja-JP',
    status: 'review',
    progress: 90,
    cost: 60.0,
    pageCount: 5,
    wordCount: 1200,
    translatorId: '4',
    createdAt: '2024-12-24T09:00:00Z',
    updatedAt: '2024-12-27T09:00:00Z',
    quality: 'certified'
  },
  {
    id: 'doc_4',
    userId: '5',
    fileName: 'Resume.pdf',
    fileSize: 256000,
    fileType: 'application/pdf',
    fileUrl: '/uploads/resumes/resume.pdf',
    sourceLanguage: 'zh-CN',
    targetLanguage: 'en-US',
    status: 'failed',
    progress: 0,
    cost: 0,
    pageCount: 2,
    wordCount: 800,
    createdAt: '2024-12-23T15:00:00Z',
    updatedAt: '2024-12-23T15:30:00Z',
    quality: 'draft'
  }
];

// 预约数据
export const mockAppointments: Appointment[] = [
  {
    id: 'apt_1',
    userId: '2',
    translatorId: '4',
    title: '商务会议翻译',
    description: '与日本客户的商务洽谈会议',
    type: 'video',
    sourceLanguage: 'zh-CN',
    targetLanguage: 'ja-JP',
    startTime: '2024-12-28T09:00:00Z',
    endTime: '2024-12-28T11:00:00Z',
    status: 'confirmed',
    cost: 180.0,
    meetingUrl: 'https://meet.translatepro.com/room/apt_1',
    notes: '需要专业商务术语翻译',
    reminderSent: true,
    createdAt: '2024-12-20T10:00:00Z',
    updatedAt: '2024-12-25T14:00:00Z'
  },
  {
    id: 'apt_2',
    userId: '3',
    translatorId: '4',
    title: '医疗咨询翻译',
    description: '与中国医生的远程医疗咨询',
    type: 'video',
    sourceLanguage: 'en-US',
    targetLanguage: 'zh-CN',
    startTime: '2024-12-29T14:00:00Z',
    endTime: '2024-12-29T15:00:00Z',
    status: 'scheduled',
    cost: 90.0,
    meetingUrl: 'https://meet.translatepro.com/room/apt_2',
    notes: '需要医疗专业术语翻译',
    reminderSent: false,
    createdAt: '2024-12-22T16:30:00Z',
    updatedAt: '2024-12-22T16:30:00Z'
  },
  {
    id: 'apt_3',
    userId: '2',
    title: '法律文件讨论',
    description: '关于合同条款的讨论',
    type: 'human',
    sourceLanguage: 'zh-CN',
    targetLanguage: 'en-US',
    startTime: '2024-12-30T10:00:00Z',
    endTime: '2024-12-30T12:00:00Z',
    status: 'scheduled',
    cost: 240.0,
    notes: '需要法律专业背景的译员',
    reminderSent: false,
    createdAt: '2024-12-25T11:00:00Z',
    updatedAt: '2024-12-25T11:00:00Z'
  },
  {
    id: 'apt_4',
    userId: '5',
    title: '旅游咨询',
    description: '关于日本旅游的咨询',
    type: 'ai',
    sourceLanguage: 'zh-CN',
    targetLanguage: 'ja-JP',
    startTime: '2024-12-24T15:00:00Z',
    endTime: '2024-12-24T15:30:00Z',
    status: 'cancelled',
    cost: 0,
    notes: '用户临时取消',
    reminderSent: true,
    createdAt: '2024-12-20T09:00:00Z',
    updatedAt: '2024-12-24T14:00:00Z'
  }
];

// 译员数据
export const mockTranslators: Translator[] = [
  {
    id: '4',
    userId: '4',
    name: '李译员',
    email: 'translator1@example.com',
    phone: '+86 138 0013 8004',
    avatar: 'https://api.dicebear.com/7.x/avataaars/svg?seed=translator1',
    languages: [
      { code: 'zh-CN', name: '中文（简体）', level: 'native' },
      { code: 'en-US', name: 'English', level: 'fluent' },
      { code: 'ja-JP', name: '日本語', level: 'fluent' }
    ],
    specializations: ['商务翻译', '法律翻译', '医疗翻译'],
    rating: 4.8,
    totalCalls: 156,
    totalHours: 234,
    hourlyRate: 90,
    status: 'available',
    certifications: [
      {
        id: 'cert_1',
        name: '全国翻译专业资格证书',
        issuer: '中国外文局',
        issueDate: '2020-06-01T00:00:00Z',
        expiryDate: '2025-06-01T00:00:00Z'
      },
      {
        id: 'cert_2',
        name: 'JLPT N1',
        issuer: '日本国际交流基金',
        issueDate: '2019-12-01T00:00:00Z'
      }
    ],
    experience: 5,
    bio: '拥有5年专业翻译经验，专长商务、法律、医疗领域翻译。',
    workingHours: {
      monday: [{ start: '09:00', end: '18:00' }],
      tuesday: [{ start: '09:00', end: '18:00' }],
      wednesday: [{ start: '09:00', end: '18:00' }],
      thursday: [{ start: '09:00', end: '18:00' }],
      friday: [{ start: '09:00', end: '18:00' }],
      saturday: [{ start: '10:00', end: '16:00' }],
      sunday: []
    },
    createdAt: '2024-01-15T00:00:00Z',
    updatedAt: '2024-12-27T08:00:00Z'
  }
];

// 支付数据
export const mockPayments: Payment[] = [
  {
    id: 'pay_1',
    userId: '2',
    amount: 15.0,
    currency: 'USD',
    status: 'completed',
    type: 'call',
    referenceId: 'call_1',
    paymentMethod: {
      id: 'pm_1',
      type: 'card',
      last4: '4242',
      brand: 'visa',
      expiryMonth: 12,
      expiryYear: 2025
    },
    createdAt: '2024-12-27T09:15:00Z',
    updatedAt: '2024-12-27T09:15:00Z',
    stripePaymentIntentId: 'pi_1234567890'
  },
  {
    id: 'pay_2',
    userId: '3',
    amount: 45.0,
    currency: 'USD',
    status: 'completed',
    type: 'call',
    referenceId: 'call_2',
    paymentMethod: {
      id: 'pm_2',
      type: 'card',
      last4: '1234',
      brand: 'mastercard',
      expiryMonth: 8,
      expiryYear: 2026
    },
    createdAt: '2024-12-26T15:00:00Z',
    updatedAt: '2024-12-26T15:00:00Z',
    stripePaymentIntentId: 'pi_0987654321'
  },
  {
    id: 'pay_3',
    userId: '2',
    amount: 120.0,
    currency: 'USD',
    status: 'completed',
    type: 'document',
    referenceId: 'doc_1',
    paymentMethod: {
      id: 'pm_1',
      type: 'card',
      last4: '4242',
      brand: 'visa',
      expiryMonth: 12,
      expiryYear: 2025
    },
    createdAt: '2024-12-26T16:30:00Z',
    updatedAt: '2024-12-26T16:30:00Z',
    stripePaymentIntentId: 'pi_1122334455'
  }
];

// 仪表板统计数据
export const mockDashboardStats: DashboardStats = {
  totalUsers: 1250,
  activeUsers: 890,
  totalCalls: 3456,
  totalDocuments: 789,
  totalRevenue: 45678.90,
  averageRating: 4.6,
  callsToday: 23,
  documentsToday: 8,
  revenueToday: 567.80,
  userGrowth: 12.5,
  callsGrowth: 8.3,
  revenueGrowth: 15.7
};

// 图表数据
export const mockChartData: ChartData[] = [
  { date: '2024-12-20', users: 45, calls: 120, documents: 25, revenue: 1234.56 },
  { date: '2024-12-21', users: 52, calls: 135, documents: 30, revenue: 1456.78 },
  { date: '2024-12-22', users: 38, calls: 98, documents: 18, revenue: 987.65 },
  { date: '2024-12-23', users: 61, calls: 156, documents: 35, revenue: 1678.90 },
  { date: '2024-12-24', users: 43, calls: 112, documents: 22, revenue: 1123.45 },
  { date: '2024-12-25', users: 55, calls: 142, documents: 28, revenue: 1345.67 },
  { date: '2024-12-26', users: 49, calls: 128, documents: 31, revenue: 1567.89 },
  { date: '2024-12-27', users: 67, calls: 178, documents: 42, revenue: 1890.12 }
];

// 系统设置
export const mockSystemSettings: SystemSettings = {
  id: 'settings_1',
  siteName: 'TranslatePro 管理后台',
  siteDescription: '专业的多语言翻译服务平台',
  supportEmail: 'support@translatepro.com',
  languages: mockLanguages,
  defaultLanguage: 'zh-CN',
  timezone: 'Asia/Shanghai',
  currency: 'USD',
  features: {
    aiTranslation: true,
    humanTranslation: true,
    videoCall: true,
    documentTranslation: true,
    appointmentBooking: true
  },
  pricing: {
    aiCallPerMinute: 1.0,
    humanCallPerMinute: 1.5,
    videoCallPerMinute: 2.0,
    documentPerPage: 10.0
  },
  limits: {
    freeCallsPerMonth: 30,
    maxFileSize: 10485760, // 10MB
    maxDocumentPages: 50
  },
  integrations: {
    twilio: {
      enabled: true,
      accountSid: 'AC***************************'
    },
    stripe: {
      enabled: true,
      publishableKey: 'pk_test_***************************'
    },
    openai: {
      enabled: true,
      apiKey: 'sk-***************************'
    }
  },
  createdAt: '2024-01-01T00:00:00Z',
  updatedAt: '2024-12-27T10:00:00Z'
};

// 通知数据
export const mockNotifications: Notification[] = [
  {
    id: 'notif_1',
    userId: '2',
    type: 'success',
    title: '文档翻译完成',
    message: '您的商业合同翻译已完成，请查看结果。',
    read: false,
    createdAt: '2024-12-27T10:30:00Z',
    updatedAt: '2024-12-27T10:30:00Z',
    actionUrl: '/documents/doc_1',
    actionText: '查看文档'
  },
  {
    id: 'notif_2',
    userId: '3',
    type: 'info',
    title: '预约提醒',
    message: '您有一个预约将在1小时后开始。',
    read: false,
    createdAt: '2024-12-27T09:00:00Z',
    updatedAt: '2024-12-27T09:00:00Z',
    actionUrl: '/appointments/apt_2',
    actionText: '查看预约'
  },
  {
    id: 'notif_3',
    type: 'warning',
    title: '系统维护通知',
    message: '系统将在今晚22:00-24:00进行维护升级。',
    read: true,
    createdAt: '2024-12-26T16:00:00Z',
    updatedAt: '2024-12-27T08:00:00Z'
  }
];

// 系统日志数据
export const mockSystemLogs: SystemLog[] = [
  {
    id: 'log_1',
    level: 'info',
    message: '用户登录成功',
    userId: '2',
    action: 'login',
    resource: 'auth',
    ip: '192.168.1.100',
    userAgent: 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36',
    createdAt: '2024-12-27T10:30:00Z'
  },
  {
    id: 'log_2',
    level: 'warn',
    message: '文档上传失败',
    userId: '5',
    action: 'upload',
    resource: 'document',
    resourceId: 'doc_4',
    ip: '192.168.1.101',
    metadata: { error: 'File size exceeds limit', fileSize: 15728640 },
    createdAt: '2024-12-27T09:45:00Z'
  },
  {
    id: 'log_3',
    level: 'error',
    message: '支付处理失败',
    userId: '3',
    action: 'payment',
    resource: 'payment',
    ip: '192.168.1.102',
    metadata: { error: 'Card declined', amount: 85.0 },
    createdAt: '2024-12-27T09:15:00Z'
  }
];

// 最近活动数据
export const mockRecentActivities = [
  {
    id: 'activity_1',
    type: 'call',
    title: '张三完成AI翻译通话',
    description: '中文→英文，时长15分钟',
    time: '2024-12-27T10:30:00Z',
    status: 'completed',
    avatar: 'https://api.dicebear.com/7.x/avataaars/svg?seed=user1'
  },
  {
    id: 'activity_2',
    type: 'document',
    title: 'John Smith上传文档翻译',
    description: '商业合同，英文→中文',
    time: '2024-12-27T09:45:00Z',
    status: 'pending',
    avatar: 'https://api.dicebear.com/7.x/avataaars/svg?seed=user2'
  },
  {
    id: 'activity_3',
    type: 'user',
    title: '新用户注册',
    description: '李四注册了Premium账户',
    time: '2024-12-27T09:15:00Z',
    status: 'completed',
    avatar: 'https://api.dicebear.com/7.x/avataaars/svg?seed=user4'
  }
];

// 通话趋势数据
export const mockCallTrends = [
  { date: '2024-12-20', count: 45 },
  { date: '2024-12-21', count: 52 },
  { date: '2024-12-22', count: 38 },
  { date: '2024-12-23', count: 61 },
  { date: '2024-12-24', count: 43 },
  { date: '2024-12-25', count: 55 },
  { date: '2024-12-26', count: 49 },
  { date: '2024-12-27', count: 67 }
];

// 收入趋势数据
export const mockRevenueTrends = [
  { date: '2024-12-20', revenue: 1234.56 },
  { date: '2024-12-21', revenue: 1456.78 },
  { date: '2024-12-22', revenue: 987.65 },
  { date: '2024-12-23', revenue: 1678.90 },
  { date: '2024-12-24', revenue: 1123.45 },
  { date: '2024-12-25', revenue: 1345.67 },
  { date: '2024-12-26', revenue: 1567.89 },
  { date: '2024-12-27', revenue: 1890.12 }
];

// 语言分布数据
export const mockLanguageDistribution = [
  { language: '中文', value: 35 },
  { language: '英文', value: 28 },
  { language: '日文', value: 15 },
  { language: '韩文', value: 12 },
  { language: '西班牙文', value: 6 },
  { language: '其他', value: 4 }
];

// 导出所有Mock数据
export const mockData = {
  users: mockUsers,
  translationCalls: mockTranslationCalls,
  documentTranslations: mockDocumentTranslations,
  appointments: mockAppointments,
  translators: mockTranslators,
  payments: mockPayments,
  dashboardStats: mockDashboardStats,
  chartData: mockChartData,
  systemSettings: mockSystemSettings,
  notifications: mockNotifications,
  systemLogs: mockSystemLogs,
  languages: mockLanguages,
  recentActivities: mockRecentActivities,
  callTrends: mockCallTrends,
  revenueTrends: mockRevenueTrends,
  languageDistribution: mockLanguageDistribution
}; 