import { 
  User, 
  CallSession, 
  DocumentTranslation, 
  Appointment, 
  Notification,
  Contract,
  Language 
} from '@/types';

// 模拟用户数据
export const mockUser: User = {
  id: 'user-123',
  email: 'test@example.com',
  role: 'client',
  idNumber: '123456789012345678',
  stripeCustomerId: 'cus_test123',
  createdAt: '2024-01-01T00:00:00Z',
  updatedAt: '2024-01-15T10:30:00Z',
};

// 模拟合约数据
export const mockContract: Contract = {
  contractId: 'contract-456',
  userId: 'user-123',
  billingType: 'per_minute',
  creditBalance: 150,
  monthlyMinutes: 300,
  createdAt: '2024-01-01T00:00:00Z',
  expiresAt: '2024-12-31T23:59:59Z',
};

// 模拟通话记录
export const mockCallSessions: CallSession[] = [
  {
    id: 'call-001',
    userId: 'user-123',
    interpreterId: 'interpreter-001',
    mode: 'human',
    sourceLanguage: 'zh',
    targetLanguage: 'en',
    status: 'completed',
    duration: 1800, // 30分钟
    cost: 45.00,
    twilioRoomId: 'room-abc123',
    recordingUrl: 'https://recordings.example.com/call-001.mp3',
    createdAt: '2024-01-15T09:00:00Z',
    endedAt: '2024-01-15T09:30:00Z',
  },
  {
    id: 'call-002',
    userId: 'user-123',
    mode: 'ai',
    sourceLanguage: 'en',
    targetLanguage: 'es',
    status: 'completed',
    duration: 900, // 15分钟
    cost: 15.00,
    twilioRoomId: 'room-def456',
    createdAt: '2024-01-14T14:30:00Z',
    endedAt: '2024-01-14T14:45:00Z',
  },
  {
    id: 'call-003',
    userId: 'user-123',
    mode: 'video',
    sourceLanguage: 'zh',
    targetLanguage: 'fr',
    status: 'cancelled',
    duration: 0,
    cost: 0,
    createdAt: '2024-01-13T16:00:00Z',
  },
];

// 模拟文档翻译数据
export const mockDocuments: DocumentTranslation[] = [
  {
    id: 'doc-001',
    userId: 'user-123',
    originalFileName: '合同文件.pdf',
    translatedFileName: 'contract_document.pdf',
    sourceLanguage: 'zh',
    targetLanguage: 'en',
    status: 'completed',
    s3Key: 'documents/original/doc-001.pdf',
    translatedS3Key: 'documents/translated/doc-001-en.pdf',
    cost: 25.00,
    createdAt: '2024-01-12T10:00:00Z',
    completedAt: '2024-01-12T12:30:00Z',
  },
  {
    id: 'doc-002',
    userId: 'user-123',
    originalFileName: '技术说明书.docx',
    sourceLanguage: 'zh',
    targetLanguage: 'en',
    status: 'review',
    s3Key: 'documents/original/doc-002.docx',
    cost: 35.00,
    reviewNotes: '专业术语需要进一步确认',
    createdAt: '2024-01-11T15:20:00Z',
  },
  {
    id: 'doc-003',
    userId: 'user-123',
    originalFileName: '用户手册.txt',
    sourceLanguage: 'en',
    targetLanguage: 'ja',
    status: 'processing',
    s3Key: 'documents/original/doc-003.txt',
    cost: 20.00,
    createdAt: '2024-01-10T08:45:00Z',
  },
];

// 模拟预约数据
export const mockAppointments: Appointment[] = [
  {
    id: 'apt-001',
    userId: 'user-123',
    interpreterId: 'interpreter-002',
    title: '商务会议翻译',
    description: '与美国客户的重要商务谈判',
    startTime: '2024-01-20T10:00:00Z',
    endTime: '2024-01-20T12:00:00Z',
    mode: 'human',
    sourceLanguage: 'zh',
    targetLanguage: 'en',
    status: 'confirmed',
    reminderSent: false,
    googleEventId: 'google-event-123',
    createdAt: '2024-01-15T14:30:00Z',
  },
  {
    id: 'apt-002',
    userId: 'user-123',
    title: 'AI翻译测试',
    description: '测试新的AI翻译功能',
    startTime: '2024-01-18T15:30:00Z',
    endTime: '2024-01-18T16:00:00Z',
    mode: 'ai',
    sourceLanguage: 'en',
    targetLanguage: 'fr',
    status: 'scheduled',
    reminderSent: true,
    createdAt: '2024-01-16T09:15:00Z',
  },
];

// 模拟通知数据
export const mockNotifications: Notification[] = [
  {
    id: 'notif-001',
    userId: 'user-123',
    title: '文档翻译完成',
    body: '您的文档"合同文件.pdf"翻译已完成，请查看结果。',
    type: 'document',
    read: false,
    data: { documentId: 'doc-001' },
    createdAt: '2024-01-15T12:30:00Z',
  },
  {
    id: 'notif-002',
    userId: 'user-123',
    title: '预约提醒',
    body: '您有一个商务会议翻译预约将在1小时后开始。',
    type: 'call',
    read: false,
    data: { appointmentId: 'apt-001' },
    createdAt: '2024-01-15T09:00:00Z',
  },
  {
    id: 'notif-003',
    userId: 'user-123',
    title: '余额不足提醒',
    body: '您的账户余额不足，请及时充值以免影响服务使用。',
    type: 'payment',
    read: true,
    createdAt: '2024-01-14T16:45:00Z',
  },
];

// 支持的语言列表
export const mockLanguages: Language[] = [
  { code: 'zh', name: 'Chinese', nativeName: '中文', flag: '🇨🇳' },
  { code: 'en', name: 'English', nativeName: 'English', flag: '🇺🇸' },
  { code: 'es', name: 'Spanish', nativeName: 'Español', flag: '🇪🇸' },
  { code: 'fr', name: 'French', nativeName: 'Français', flag: '🇫🇷' },
  { code: 'de', name: 'German', nativeName: 'Deutsch', flag: '🇩🇪' },
  { code: 'ja', name: 'Japanese', nativeName: '日本語', flag: '🇯🇵' },
  { code: 'ko', name: 'Korean', nativeName: '한국어', flag: '🇰🇷' },
  { code: 'ru', name: 'Russian', nativeName: 'Русский', flag: '🇷🇺' },
  { code: 'ar', name: 'Arabic', nativeName: 'العربية', flag: '🇸🇦' },
  { code: 'pt', name: 'Portuguese', nativeName: 'Português', flag: '🇵🇹' },
];

// 模拟统计数据
export const mockUsageStats = {
  totalCalls: 25,
  totalMinutes: 1250,
  totalDocuments: 12,
  totalSpent: 485.50,
  monthlyBreakdown: [
    { month: '2024-01', calls: 8, minutes: 420, cost: 165.00 },
    { month: '2023-12', calls: 12, minutes: 580, cost: 220.50 },
    { month: '2023-11', calls: 5, minutes: 250, cost: 100.00 },
  ],
};

// 获取随机模拟数据的工具函数
export const getRandomCallSession = (): CallSession => {
  const modes: Array<'ai' | 'human' | 'video' | 'sign'> = ['ai', 'human', 'video', 'sign'];
  const statuses: Array<'pending' | 'active' | 'completed' | 'cancelled'> = ['completed', 'cancelled'];
  const languages = ['zh', 'en', 'es', 'fr', 'de', 'ja'];
  
  return {
    id: `call-${Date.now()}`,
    userId: 'user-123',
    mode: modes[Math.floor(Math.random() * modes.length)],
    sourceLanguage: languages[Math.floor(Math.random() * languages.length)],
    targetLanguage: languages[Math.floor(Math.random() * languages.length)],
    status: statuses[Math.floor(Math.random() * statuses.length)],
    duration: Math.floor(Math.random() * 3600), // 0-60分钟
    cost: Math.floor(Math.random() * 100) + 10, // 10-110美元
    createdAt: new Date(Date.now() - Math.random() * 7 * 24 * 60 * 60 * 1000).toISOString(),
  };
};

export const getRandomDocument = (): DocumentTranslation => {
  const statuses: Array<'uploading' | 'processing' | 'review' | 'completed' | 'failed'> = 
    ['processing', 'review', 'completed'];
  const fileNames = ['文档1.pdf', '合同.docx', '说明书.txt', '报告.xlsx'];
  const languages = ['zh', 'en', 'es', 'fr', 'de', 'ja'];
  
  return {
    id: `doc-${Date.now()}`,
    userId: 'user-123',
    originalFileName: fileNames[Math.floor(Math.random() * fileNames.length)],
    sourceLanguage: languages[Math.floor(Math.random() * languages.length)],
    targetLanguage: languages[Math.floor(Math.random() * languages.length)],
    status: statuses[Math.floor(Math.random() * statuses.length)],
    s3Key: `documents/original/doc-${Date.now()}.pdf`,
    cost: Math.floor(Math.random() * 50) + 10, // 10-60美元
    createdAt: new Date(Date.now() - Math.random() * 7 * 24 * 60 * 60 * 1000).toISOString(),
  };
}; 